aboutsummaryrefslogtreecommitdiffstats
path: root/Projects/AVRISP-MKII/Lib/ISP/ISPTarget.c
diff options
context:
space:
mode:
authorDean Camera <dean@fourwalledcubicle.com>2011-06-05 13:55:56 +0000
committerDean Camera <dean@fourwalledcubicle.com>2011-06-05 13:55:56 +0000
commit7dffa15c1670806cc053b9930f341b53e30f7384 (patch)
treeb06af7dc2e6e2cf9f5bf20cb848cff5ee3f527c8 /Projects/AVRISP-MKII/Lib/ISP/ISPTarget.c
parent0210fa5648b1ed65caa384f966ac40b4ecc489ae (diff)
downloadlufa-7dffa15c1670806cc053b9930f341b53e30f7384.tar.gz
lufa-7dffa15c1670806cc053b9930f341b53e30f7384.tar.bz2
lufa-7dffa15c1670806cc053b9930f341b53e30f7384.zip
Massive corrections to the project documentation and code comments, thanks to Russian translation services provided by Andrey from Microsin.ru.
Diffstat (limited to 'Projects/AVRISP-MKII/Lib/ISP/ISPTarget.c')
-rw-r--r--Projects/AVRISP-MKII/Lib/ISP/ISPTarget.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/Projects/AVRISP-MKII/Lib/ISP/ISPTarget.c b/Projects/AVRISP-MKII/Lib/ISP/ISPTarget.c
index f08ee6a0e..9e7260aef 100644
--- a/Projects/AVRISP-MKII/Lib/ISP/ISPTarget.c
+++ b/Projects/AVRISP-MKII/Lib/ISP/ISPTarget.c
@@ -161,7 +161,7 @@ void ISPTarget_EnableTargetISP(void)
DDRB |= ((1 << 1) | (1 << 2));
PORTB |= ((1 << 0) | (1 << 3));
- ISPTarget_ConfigureSoftwareISP(SCKDuration);
+ ISPTarget_ConfigureSoftwareSPI(SCKDuration);
}
}
@@ -185,7 +185,7 @@ void ISPTarget_DisableTargetISP(void)
}
}
-/** Configures the AVR to produce a .5MHz rescue clock out of the OCR1A pin of the AVR, so
+/** Configures the AVR to produce a 4MHz rescue clock out of the OCR1A pin of the AVR, so
* that it can be fed into the XTAL1 pin of an AVR whose fuses have been mis-configured for
* an external clock rather than a crystal. When used, the ISP speed must be 125KHz for this
* functionality to work correctly.
@@ -217,14 +217,14 @@ void ISPTarget_ConfigureRescueClock(void)
#endif
}
/** Configures the AVR's timer ready to produce software ISP for the slower ISP speeds that
* cannot be obtained when using the AVR's hardware SPI module.
*
* \param[in] SCKDuration Duration of the desired software ISP SCK clock
*/
-void ISPTarget_ConfigureSoftwareISP(const uint8_t SCKDuration)
+void ISPTarget_ConfigureSoftwareSPI(const uint8_t SCKDuration)
{
/* Configure Timer 1 for software ISP using the specified SCK duration */
TIMSK1 = (1 << OCIE1A);
TCNT1 = 0;
OCR1A = pgm_read_word(&TimerCompareFromSCKDuration[SCKDuration - sizeof(SPIMaskFromSCKDuration)]);
@@ -217,14 +217,14 @@ void ISPTarget_ConfigureRescueClock(void)
#endif
}
-/** Configures the AVR's timer ready to produce software ISP for the slower ISP speeds that
+/** Configures the AVR's timer ready to produce software SPI for the slower ISP speeds that
* cannot be obtained when using the AVR's hardware SPI module.
*
@@ -217,14 +217,14 @@ void ISPTarget_ConfigureRescueClock(void)
{
- /* Configure Timer 1 for software ISP using the specified SCK duration */
+ /* Configure Timer 1 for software SPI using the specified SCK duration */
TIMSK1 = (1 << OCIE1A);
TCNT1 = 0;